@@ -15,21 +15,23 @@ class EntityNewsResource(Resource):
     @jwt_required()
     def get(self, entity_id):
         """
-        Retrieve all news linked to a given entity.
+        Get entity news
         ---
+        description: Retrieve all news entries that are linked to a specific
+          entity.
         tags:
           - Entities
         parameters:
           - in: path
             name: entity_id
             required: true
-            schema:
-              type: string
-              format: uuid
+            type: string
+            format: uuid
             example: a24a6ea4-ce75-4665-a070-57453082c25
+            description: Unique identifier of the entity
         responses:
-          '200':
-            description: All news linked to given entity
+          200:
+            description: List of entity news successfully retrieved
             content:
               application/json:
                 schema:
@@ -40,21 +42,42 @@ class EntityNewsResource(Resource):
                       id:
                         type: string
                         format: uuid
-                      title:
-                        type: string
-                      content:
-                        type: string
-                      created_at:
-                        type: string
-                        format: date-time
+                        description: News unique identifier
+                        example: a24a6ea4-ce75-4665-a070-57453082c25
+                      change:
+                        type: boolean
+                        description: Whether this news represents a change
+                        example: true
                       author_id:
                         type: string
                         format: uuid
-                      entity_id:
+                        description: Author person identifier
+                        example: b35b7fb5-df86-5776-b181-68564193d36
+                      comment_id:
                         type: string
                         format: uuid
-          '404':
-            description: Entity not found
+                        description: Comment identifier
+                        example: c46c8gc6-eg97-6887-c292-79675204e47
+                      task_id:
+                        type: string
+                        format: uuid
+                        description: Task identifier
+                        example: d57d9hd7-fh08-7998-d403-80786315f58
+                      preview_file_id:
+                        type: string
+                        format: uuid
+                        description: Preview file identifier
+                        example: e68e0ie8-gi19-8009-e514-91897426g69
+                      created_at:
+                        type: string
+                        format: date-time
+                        description: Creation timestamp
+                        example: "2023-01-01T12:00:00Z"
+                      updated_at:
+                        type: string
+                        format: date-time
+                        description: Last update timestamp
+                        example: "2023-01-01T12:30:00Z"
         """
         entity = entities_service.get_entity(entity_id)
         user_service.check_project_access(entity["project_id"])
@@ -65,21 +88,24 @@ class EntityPreviewFilesResource(Resource):
     @jwt_required()
     def get(self, entity_id):
         """
-        Retrieve all preview files linked to a given entity.
+        Get entity preview files
         ---
+        description: Retrieve all preview files that are linked to a specific
+          entity. This includes images, videos, and other preview media
+          associated with the entity.
         tags:
           - Entities
         parameters:
           - in: path
             name: entity_id
             required: true
-            schema:
-              type: string
-              format: uuid
+            type: string
+            format: uuid
             example: a24a6ea4-ce75-4665-a070-57453082c25
+            description: Unique identifier of the entity
         responses:
-          '200':
-            description: All preview files linked to given entity
+          200:
+            description: List of entity preview files successfully retrieved
             content:
               application/json:
                 schema:
@@ -90,23 +116,35 @@ class EntityPreviewFilesResource(Resource):
                       id:
                         type: string
                         format: uuid
+                        description: Preview file unique identifier
+                        example: a24a6ea4-ce75-4665-a070-57453082c25
                       name:
                         type: string
+                        description: Preview file name
+                        example: "preview_001.jpg"
                       path:
                         type: string
+                        description: File path
+                        example: "/previews/entity/preview_001.jpg"
                       revision:
                         type: integer
+                        description: File revision number
+                        example: 1
                       created_at:
                         type: string
                         format: date-time
+                        description: Creation timestamp
+                        example: "2023-01-01T12:00:00Z"
                       entity_id:
                         type: string
                         format: uuid
+                        description: Entity identifier
+                        example: b35b7fb5-df86-5776-b181-68564193d36
                       task_id:
                         type: string
                         format: uuid
-          '404':
-            description: Entity not found
+                        description: Task identifier
+                        example: c46c8gc6-eg97-6887-c292-79675204e47
         """
         entity = entities_service.get_entity(entity_id)
         user_service.check_project_access(entity["project_id"])
@@ -117,21 +155,23 @@ class EntityTimeSpentsResource(Resource):
     @jwt_required()
     def get(self, entity_id):
         """
-        Retrieve all time spents linked to a given entity.
+        Get entity time spent
         ---
+        description: Retrieve all time spent entries that are linked to a
+          specific entity.
         tags:
           - Entities
         parameters:
           - in: path
             name: entity_id
             required: true
-            schema:
-              type: string
-              format: uuid
+            type: string
+            format: uuid
             example: a24a6ea4-ce75-4665-a070-57453082c25
+            description: Unique identifier of the entity
         responses:
-          '200':
-            description: All time spents linked to given entity
+          200:
+            description: List of entity time spent entries successfully retrieved
             content:
               application/json:
                 schema:
@@ -142,25 +182,33 @@ class EntityTimeSpentsResource(Resource):
                       id:
                         type: string
                         format: uuid
+                        description: Time spent unique identifier
+                        example: a24a6ea4-ce75-4665-a070-57453082c25
                       duration:
                         type: number
                         format: float
+                        description: Time duration in hours
                         example: 2.5
                       date:
                         type: string
                         format: date
+                        description: Date when time was spent
                         example: "2023-12-07"
                       created_at:
                         type: string
                         format: date-time
+                        description: Creation timestamp
+                        example: "2023-01-01T12:00:00Z"
                       person_id:
                         type: string
                         format: uuid
+                        description: Person identifier who spent the time
+                        example: b35b7fb5-df86-5776-b181-68564193d36
                       entity_id:
                         type: string
                         format: uuid
-          '404':
-            description: Entity not found
+                        description: Entity identifier
+                        example: c46c8gc6-eg97-6887-c292-79675204e47
         """
         entity = entities_service.get_entity(entity_id)
         user_service.check_project_access(entity["project_id"])
@@ -171,21 +219,24 @@ class EntitiesLinkedWithTasksResource(Resource):
     @jwt_required()
     def get(self, entity_id):
         """
-        Resource to retrieve the entities linked on a given entity.
+        Get linked entities
         ---
+        description: Retrieve all entities that are linked to a specific entity
+          along with their associated tasks. This includes related entities,
+          dependencies, and hierarchical relationships.
         tags:
           - Entities
         parameters:
           - in: path
             name: entity_id
             required: true
-            schema:
-              type: string
-              format: uuid
+            type: string
+            format: uuid
             example: a24a6ea4-ce75-4665-a070-57453082c25
+            description: Unique identifier of the entity
         responses:
-          '200':
-            description: Entities linked on given entity
+          200:
+            description: List of linked entities successfully retrieved
             content:
               application/json:
                 schema:
@@ -196,17 +247,27 @@ class EntitiesLinkedWithTasksResource(Resource):
                       id:
                         type: string
                         format: uuid
+                        description: Entity unique identifier
+                        example: a24a6ea4-ce75-4665-a070-57453082c25
                       name:
                         type: string
+                        description: Entity name
+                        example: "Character Model"
                       entity_type_id:
                         type: string
                         format: uuid
+                        description: Entity type identifier
+                        example: b35b7fb5-df86-5776-b181-68564193d36
                       project_id:
                         type: string
                         format: uuid
+                        description: Project identifier
+                        example: c46c8gc6-eg97-6887-c292-79675204e47
                       parent_id:
                         type: string
                         format: uuid
+                        description: Parent entity identifier
+                        example: d57d9hd7-fh08-7998-d403-80786315f58
                       tasks:
                         type: array
                         items:
@@ -215,13 +276,17 @@ class EntitiesLinkedWithTasksResource(Resource):
                             id:
                               type: string
                               format: uuid
+                              description: Task unique identifier
+                              example: e68e0ie8-gi19-8009-e514-91897426g69
                             name:
                               type: string
+                              description: Task name
+                              example: "Modeling Task"
                             task_type_id:
                               type: string
                               format: uuid
-          '404':
-            description: Entity not found
+                              description: Task type identifier
+                              example: f79f1jf9-hj20-9010-f625-02998537h80
         """
         entity = entities_service.get_entity(entity_id)
         user_service.check_project_access(entity["project_id"])
