@@ -22,28 +22,66 @@ from zou.app.utils import events, cache, string
 class AssetsCsvImportResource(BaseCsvProjectImportResource):
     def post(self, project_id):
         """
-        Import project assets via a .csv file.
+        Import assets csv
         ---
         tags:
           - Import
+        description: Import project assets from a CSV file. Creates or updates
+          assets based on CSV rows. Supports metadata descriptors and task
+          status updates.
         consumes:
           - multipart/form-data
         parameters:
           - in: path
             name: project_id
-            required: True
-            type: string
-            format: uuid
+            required: true
+            schema:
+              type: string
+              format: uuid
             example: a24a6ea4-ce75-4665-a070-57453082c25
+          - in: query
+            name: update
+            required: false
+            schema:
+              type: boolean
+            default: false
+            example: false
+            description: Whether to update existing assets
           - in: formData
             name: file
             type: file
             required: true
+            description: CSV file with asset data
         responses:
             201:
-                description: The lists of imported assets.
+              description: Assets imported successfully
+              content:
+                application/json:
+                  schema:
+                    type: array
+                    items:
+                      type: object
+                      properties:
+                        id:
+                          type: string
+                          format: uuid
+                          example: a24a6ea4-ce75-4665-a070-57453082c25
+                        name:
+                          type: string
+                          example: Character A
+                        project_id:
+                          type: string
+                          format: uuid
+                          example: b24a6ea4-ce75-4665-a070-57453082c25
+                        entity_type_id:
+                          type: string
+                          format: uuid
+                          example: c24a6ea4-ce75-4665-a070-57453082c25
+                        description:
+                          type: string
+                          example: Main character asset
             400:
-                description: The .csv file is not properly formatted.
+              description: Invalid CSV format or missing required columns
         """
         return super().post(project_id)
 
