@@ -41,8 +41,39 @@ mapping_substitutions_to_regex = {
 
 
 class OTIOBaseResource(Resource, ArgsMixin):
+
     @jwt_required()
     def post(self, project_id, episode_id=None):
+        """
+        Import otio base
+        ---
+        description: Base resource for importing OTIO files. This method is
+          overridden by subclasses. Import an OTIO file to set frame_in,
+          frame_out, and nb_frames for shots.
+        tags:
+          - Import
+        consumes:
+          - multipart/form-data
+        parameters:
+          - in: path
+            name: project_id
+            required: true
+            schema:
+              type: string
+              format: uuid
+            description: Project unique identifier
+            example: a24a6ea4-ce75-4665-a070-57453082c25
+          - in: formData
+            name: file
+            type: file
+            required: true
+            description: OTIO file to import (EDL, OTIO, etc.)
+        responses:
+          201:
+            description: Shots imported successfully
+          400:
+            description: Invalid file format or parsing error
+        """
         args = self.post_args()
         user_service.check_manager_project_access(project_id)
         uploaded_file = request.files["file"]
@@ -269,33 +300,114 @@ class OTIOBaseResource(Resource, ArgsMixin):
 
 
 class OTIOImportResource(OTIOBaseResource):
+
     @jwt_required()
     def post(self, **kwargs):
         """
-        Import an OTIO file to enter frame_in / frame_out / nb_frames (it can
-        be every adapter supported by OpenTimelineIO, for example: EDL, OTIO...
-        ).
+        Import otio EDL
         ---
         tags:
           - Import
+        description: Import an OTIO file to set frame_in, frame_out, and
+          nb_frames for shots. Supports any OpenTimelineIO adapter format like
+          EDL or OTIO. Uses naming convention to match shots.
         consumes:
           - multipart/form-data
         parameters:
           - in: path
             name: project_id
-            required: True
-            type: string
-            format: uuid
+            required: true
+            schema:
+              type: string
+              format: uuid
             example: a24a6ea4-ce75-4665-a070-57453082c25
+          - in: query
+            name: naming_convention
+            required: false
+            schema:
+              type: string
+            default: "${project_name}_${sequence_name}-${shot_name}"
+            example: "${project_name}_${sequence_name}-${shot_name}"
+            description: Template for matching shot names from the file
+          - in: query
+            name: match_case
+            required: false
+            schema:
+              type: boolean
+            default: true
+            example: true
+            description: Whether to match shot names case-sensitively
           - in: formData
             name: file
             type: file
             required: true
+            description: OTIO file to import (EDL, OTIO, etc.)
         responses:
             201:
-                description: .
+              description: Shots imported successfully
+              content:
+                application/json:
+                  schema:
+                    type: object
+                    properties:
+                      updated_shots:
+                        type: array
+                        items:
+                          type: object
+                          properties:
+                            id:
+                              type: string
+                              format: uuid
+                              example: a24a6ea4-ce75-4665-a070-57453082c25
+                            name:
+                              type: string
+                              example: SH010
+                            project_id:
+                              type: string
+                              format: uuid
+                              example: b24a6ea4-ce75-4665-a070-57453082c25
+                            nb_frames:
+                              type: integer
+                              example: 120
+                            data:
+                              type: object
+                              properties:
+                                frame_in:
+                                  type: integer
+                                  example: 1001
+                                frame_out:
+                                  type: integer
+                                  example: 1120
+                      created_shots:
+                        type: array
+                        items:
+                          type: object
+                          properties:
+                            id:
+                              type: string
+                              format: uuid
+                              example: c24a6ea4-ce75-4665-a070-57453082c25
+                            name:
+                              type: string
+                              example: SH020
+                            project_id:
+                              type: string
+                              format: uuid
+                              example: b24a6ea4-ce75-4665-a070-57453082c25
+                            nb_frames:
+                              type: integer
+                              example: 96
+                            data:
+                              type: object
+                              properties:
+                                frame_in:
+                                  type: integer
+                                  example: 2001
+                                frame_out:
+                                  type: integer
+                                  example: 2096
             400:
-                description: The .otio file is not properly formatted.
+              description: Invalid file format or parsing error
         """
         return super().post(**kwargs)
 
@@ -314,39 +426,122 @@ class OTIOImportResource(OTIOBaseResource):
 
 
 class OTIOImportEpisodeResource(OTIOBaseResource):
+
     @jwt_required()
     def post(self, **kwargs):
         """
-        Import an OTIO file to enter frame_in / frame_out / nb_frames (it can
-        be every adapter supported by OpenTimelineIO, for example: edl, otio...
-        ).
+        Import episode otio
         ---
         tags:
           - Import
+        description: Import an OTIO file to set frame_in, frame_out, and
+          nb_frames for shots in an episode. Supports any OpenTimelineIO
+          adapter format like EDL or OTIO. Uses naming convention with episode
+          name to match shots.
         consumes:
           - multipart/form-data
         parameters:
           - in: path
             name: project_id
-            required: True
-            type: string
-            format: uuid
+            required: true
+            schema:
+              type: string
+              format: uuid
             example: a24a6ea4-ce75-4665-a070-57453082c25
           - in: path
             name: episode_id
-            required: True
-            type: string
-            format: uuid
-            example: a24a6ea4-ce75-4665-a070-57453082c25
+            required: true
+            schema:
+              type: string
+              format: uuid
+            example: b24a6ea4-ce75-4665-a070-57453082c25
+          - in: query
+            name: naming_convention
+            required: false
+            schema:
+              type: string
+            default: "${project_name}_${episode_name}-${sequence_name}-${shot_name}"
+            example: "${project_name}_${episode_name}-${sequence_name}-${shot_name}"
+            description: Template for matching shot names from the file
+          - in: query
+            name: match_case
+            required: false
+            schema:
+              type: boolean
+            default: true
+            example: true
+            description: Whether to match shot names case-sensitively
           - in: formData
             name: file
             type: file
             required: true
+            description: OTIO file to import (EDL, OTIO, etc.)
         responses:
             201:
-                description: .
+              description: Shots imported successfully
+              content:
+                application/json:
+                  schema:
+                    type: object
+                    properties:
+                      updated_shots:
+                        type: array
+                        items:
+                          type: object
+                          properties:
+                            id:
+                              type: string
+                              format: uuid
+                              example: a24a6ea4-ce75-4665-a070-57453082c25
+                            name:
+                              type: string
+                              example: SH010
+                            project_id:
+                              type: string
+                              format: uuid
+                              example: c24a6ea4-ce75-4665-a070-57453082c25
+                            nb_frames:
+                              type: integer
+                              example: 120
+                            data:
+                              type: object
+                              properties:
+                                frame_in:
+                                  type: integer
+                                  example: 1001
+                                frame_out:
+                                  type: integer
+                                  example: 1120
+                      created_shots:
+                        type: array
+                        items:
+                          type: object
+                          properties:
+                            id:
+                              type: string
+                              format: uuid
+                              example: d24a6ea4-ce75-4665-a070-57453082c25
+                            name:
+                              type: string
+                              example: SH020
+                            project_id:
+                              type: string
+                              format: uuid
+                              example: c24a6ea4-ce75-4665-a070-57453082c25
+                            nb_frames:
+                              type: integer
+                              example: 96
+                            data:
+                              type: object
+                              properties:
+                                frame_in:
+                                  type: integer
+                                  example: 2001
+                                frame_out:
+                                  type: integer
+                                  example: 2096
             400:
-                description: The .otio file is not properly formatted.
+              description: Invalid file format or parsing error
         """
         return super().post(**kwargs)
 
