@@ -3,6 +3,8 @@ from sqlalchemy.exc import IntegrityError
 
 
 from zou.app.models.attachment_file import AttachmentFile
+from zou.app.models.budget import Budget
+from zou.app.models.budget_entry import BudgetEntry
 from zou.app.models.comment import Comment
 from zou.app.models.desktop_login_log import DesktopLoginLog
 from zou.app.models.entity import (
@@ -118,6 +120,10 @@ def remove_task(task_id, force=False):
         for subscription in subscriptions:
             subscription.delete()
 
+        working_files = WorkingFile.query.filter_by(task_id=task_id)
+        for working_file in working_files:
+            working_file.delete()
+
         preview_files = PreviewFile.query.filter_by(task_id=task_id)
         for preview_file in preview_files:
             remove_preview_file(preview_file)
@@ -342,6 +348,11 @@ def remove_project(project_id):
     for task in tasks:
         remove_task(task.id, force=True)
 
+    budgets = Budget.get_all_by(project_id=project_id)
+    for budget in budgets:
+        BudgetEntry.delete_all_by(budget_id=budget.id)
+        budget.delete()
+
     EntityLink.query.filter(
         EntityLink.entity_in_id == Entity.id,
         Entity.project_id == project_id,
